import PropTypes from 'prop-types';
import React, {Component} from 'react';
import {Link, Redirect} from 'react-router-dom'
import moment from 'moment';
import _ from 'lodash';


import ResourceDisplayList from '../../components/Resources/ResourceDisplayList';

import AppLoader from '../../layout/components/AppLoader';
import PageHeader from '../../layout/components/PageHeader';
import CycleService from '../../services/cycle.service';
import UnitConverter from '../../utils/unit.converter';
import UIConstants from '../../utils/ui.constants';
import {ProjectList} from './../Project/list';
import AuthUtil from '../../utils/auth.util';
import AccessDenied from '../../layout/components/AccessDenied';

/**
 * Component to view the details of a cycle
 */
export class CycleView extends Component {
 //   The DATE_FORMAT is  'YYYY-MM-DD HH:mm:ss';
    constructor(props) {
        super(props);
        this.state = {
            isLoading: true,
            cycle:'',
            userrole: {
                userRolePermission: {}
            }
        };
        if (this.props.match.params.id) {
            this.state.cycleId  = this.props.match.params.id;
        }   else if (this.props.location.state && this.props.location.state.id) {
            this.state.cycleId = this.props.location.state.id;
        }
        this.cancelView = this.cancelView.bind(this);
        this.state.redirect = this.state.cycleId?"":'/cycle'         // If no cycle id is passed, redirect to cycle list page
        this.resourceUnitMap = UnitConverter.resourceUnitMap;       // Resource unit conversion factor and constraints
    }

    async componentDidMount() {
        const cycleId = this.state.cycleId;
        const permission = await AuthUtil.getUserRolePermission();
        if (cycleId) {
            this.getCycleDetails();
        }   else {
            this.setState({redirect: "/not-found"});
        }
        this.setState({userrole: permission});
    }

    cancelView(){
        this.props.history.length>1?this.props.history.goBack():this.props.history.push(`/cycle`);
    }

    /**
     * To get the cycle details from the backend using the service
     * 
     */
    async getCycleDetails() {
        let cycle = await CycleService.getCycleDetails(this.state.cycleId);
        let cycleQuota = [];
        let resources = [];

        if (cycle) {
            // If resources are allocated for the cycle quota fetch the resources master from the API
            if (cycle.quota) {
                resources = await CycleService.getResources();
            }

            // For every cycle quota, get the resource type & assign to the resource variable of the quota object
            for (const id of cycle.quota_ids) {
                let quota = await CycleService.getCycleQuota(id);
                let resource = _.find(resources, ['name', quota.resource_type_id]);
                quota.resource = resource;
                cycleQuota.push(quota);
            }
            this.setState({cycle: cycle, cycleQuota: cycleQuota, isLoading: false});
        }   else {
            this.setState({redirect: "../../not-found"})
        }
        
    }

    render() {
        if (this.state.redirect) {
            return <Redirect to={ {pathname: this.state.redirect} }></Redirect>
        }
        const  {cycle}  = this.state.userrole.userRolePermission;
        return (
            <React.Fragment>
             {cycle && cycle.list?
                <>
                <PageHeader location={this.props.location} title={'Cycle - Details'} 
                            actions={[ {icon:'fa-edit', 
                                        title:cycle.edit?'Click to Edit Cycle': `Don't have permission to edit`, 
                                        disabled: cycle.edit? !cycle.edit:true,
                                        props:{ pathname: `/cycle/edit/${this.state.cycle.name}`, 
                                        state: {id: this.state.cycle?this.state.cycle.name:''}}},
                                        {icon: 'fa-window-close',
                                         type: 'button',  actOn: 'click', props:{ callback: this.cancelView }}]}/>
                { this.state.isLoading && <AppLoader /> }
                { this.state.cycle &&
                        <div className="main-content">
                            <div className="p-grid">
                                <label className="col-lg-2 col-md-2 col-sm-12">Name</label>
                                <span className="col-lg-4 col-md-4 col-sm-12">{this.state.cycle.name}</span>
                                <label className="col-lg-2 col-md-2 col-sm-12">Description</label>
                                <span className="col-lg-4 col-md-4 col-sm-12">{this.state.cycle.description}</span>
                            </div>
                            <div className="p-grid">
                                <label className="col-lg-2 col-md-2 col-sm-12">Start Time</label>
                                <span className="col-lg-4 col-md-4 col-sm-12">{moment.utc(this.state.cycle.start).format(UIConstants.CALENDAR_DATETIME_FORMAT)}</span>
                                <label className="col-lg-2 col-md-2 col-sm-12">End Time</label>
                                <span className="col-lg-4 col-md-4 col-sm-12">{moment.utc(this.state.cycle.stop).format(UIConstants.CALENDAR_DATETIME_FORMAT)}</span>
                            </div>
                            
                            {/* <div className="p-grid">
                                <label className="col-lg-2 col-md-2 col-sm-12">Projects</label>
                                <Chips className="col-lg-4 col-md-4 col-sm-12 chips-readonly" disabled value={this.state.cycle.projects_ids}></Chips>
                            </div> */}
                            <div className="p-fluid">
                                <div className="p-field p-grid">
                                    <div className="col-lg-3 col-md-3 col-sm-12">
                                        <h5 data-testid="resource_alloc">Resource Allocations</h5>
                                    </div>
                                </div>
                            </div>
                            {this.state.cycleQuota.length===0 && 
                                <div className="p-field p-grid">
                                    <div className="col-lg-12 col-md-12 col-sm-12">
                                        <span>Reosurces not yet allocated. 
                                            <Link to={{ pathname: `/cycle/edit/${this.state.cycle.name}`, state: {id: this.state.cycle?this.state.cycle.name:''}}} title="Edit Cycle" > Click</Link> to add.
                                        </span>
                                    </div>
                                </div>
                            }
                            <div className="p-field p-grid resource-input-grid">
                                <ResourceDisplayList quota={this.state.cycleQuota}  unitMap={this.resourceUnitMap} />
                            </div>
                            {/* Show Project list for this Cycle */}
                            <div className="p-fluid">
                                <div className="p-field p-grid">
                                    <div className="col-lg-3 col-md-3 col-sm-12">
                                        <h5 data-testid="project-list">Projects</h5>
                                    </div>
                                </div>
                            </div>
                            <ProjectList cycle={this.state.cycle.name}/>
                        </div>
                }
                </>: <AccessDenied/>}
            </React.Fragment>
        );
    }
}

CycleView.propTypes = {
  match: PropTypes.object,
  location: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
  history: PropTypes.object
}
