import PropTypes from 'prop-types';
import {MultiSelect} from "primereact/multiselect";
import {Dropdown} from "primereact/dropdown";
import UIConstants from "../../../utils/ui.constants";
import UtilService from "../../../services/util.service";
import ScheduleService from "../../../services/schedule.service";

function purposeFilter(selectedPurpose, allPurposes, localStoreKey, setState) {
    return <MultiSelect inputId="observStrategyPurpose"
                        optionLabel="name"
                        optionValue="value"
                        className="observ_strategy_purpose"
                        tooltip="Filter Observation Strategy by Purpose"
                        tooltipOptions={UIConstants.tooltipOptions}
                        value={selectedPurpose}
                        options={allPurposes}
                        maxSelectedLabels="1"
                        selectedItemsLabel="{0} Selected"
                        data-testid="strategy-purpose"
                        onChange={(e) => setObservationStrategyFilters(e.value, 'purpose', localStoreKey, setState)}
                        placeholder="Purpose"/>;
}

function stateFilter(selectedState, allStates, localStoreKey, setState) {
    return <MultiSelect inputId="observStrategyState"
                        optionLabel="name"
                        optionValue="value"
                        className="observ_strategy_state"
                        tooltip="Filter Observation Strategy by State"
                        tooltipOptions={UIConstants.tooltipOptions}
                        value={selectedState}
                        options={allStates}
                        onChange={(e) => setObservationStrategyFilters(e.value, 'state', localStoreKey, setState)}
                        maxSelectedLabels="1"
                        selectedItemsLabel="{0} Selected"
                        data-testid="strategy-state"
                        placeholder="State"/>;
}

function strategySelector(selectedObservationStrategy, allObservationStrategies, observationIdSet, changeStrategy) {
    const dropdown = <Dropdown inputId="observStrategy"
                               optionLabel="uniqueId"
                               optionValue="id"
                               style={{width: "100%"}}
                               data-testid="observStrategy"
                               tooltip="Observation Strategy Template to be used to create the Scheduling Unit and Tasks. Strategies already used are highlighted in bold"
                               tooltipOptions={UIConstants.tooltipOptions}
                               value={selectedObservationStrategy.id}
                               options={allObservationStrategies} filter
                               itemTemplate={option => optionTemplate(option, observationIdSet)}
                               onChange={(e) => changeStrategy(e.value)}
                               placeholder="Select Strategy"/>;
    return <div>
        {dropdown}
        <label className="info">
            {selectedObservationStrategy ? selectedObservationStrategy.description : "Select Observation Strategy"}
        </label>
    </div>;
}

/**
 * Template for displaying the options in the dropdown
 * @param option: strategy's description, name, purpose_value, state_value, version
 * @param observationIdSet set of strategy Id's that have been used before (empty array if none)
 * @return {JSX.Element}
 */
export const optionTemplate = (option, observationIdSet) => {
    if (observationIdSet) {
        return (
            <div
                title={option.description}
                style={{
                    display: "flex", fontWeight: observationIdSet.includes(option.id) ? 'bold' : 'normal'
                }}>
                {`${option.name} (${option.purpose_value}, ${option.state_value}, v${option.version})`}
            </div>
        );
    }
};

export async function queryMatchingObservationStrategyTemplates(filters) {
    let filterQueryParams = '';
    filters.states?.forEach(state => filterQueryParams += `state=${state}&`)
    filters.purpose?.forEach(purpose => filterQueryParams += `purpose=${purpose}&`)

    return await ScheduleService.getObservationStrategies(filterQueryParams);
}

/**
 * Based upon the selected filters + the stored filters (if present), it retrieves the observation strategy templates
 * via the API and sets these values in the parent component
 * @param selectedFilter the values from the multiselect element
 * @param filterId the id related to which multiselect element
 * @param localStoreKey key that points to the correct local storage (since this function is used of multiple components)
 * @param setState callback function to parent component
 */
export async function setObservationStrategyFilters(selectedFilter, filterId, localStoreKey, setState) {
    let storedFilters = await UtilService.localStore({type: 'get', key: localStoreKey});

    if (Object.keys(storedFilters).length === 0) {
        storedFilters = {states: ['active'], purpose: []}
    }

    if (filterId === 'purpose') {
        storedFilters.purpose = selectedFilter;
    } else if (filterId === 'state') { //TODO: 'state' and 'states' are mixed throughout the application (unwanted)
        storedFilters.states = selectedFilter;
    } else {
        //reset: do nothing
    }

    await UtilService.localStore({type: 'set', key: localStoreKey, value: storedFilters});

    setState({
        observStrategyFilters: storedFilters,
        observStrategies: await queryMatchingObservationStrategyTemplates(storedFilters),
        paramsSchema: null,
        observStrategy: {},
        rowData: []
    })
}

/**
 * @prop selectedPurpose Object{name<string>, value<string>}
 * @prop allPurposes list<Object{name<string>, value<string>}>
 * @prop selectedState list<string> (multi-select)
 * @prop allStates list<Object{name<string>, value<string>}>
 * @prop selectedObservationStrategy list<string> (multi-select)
 * @prop allObservationStrategies list<string>
 * @prop observationIdSet list<integer> set of strategy Id's that have been used before (empty array if none)
 * @prop changeStrategy function: callback
 * @prop localStoreKey <string>
 * @prop setState function: callback (for strategy filters)
 * @return {JSX.Element}
 */
export default function ObservationStrategySelector(props) {
    const {
        selectedPurpose,
        allPurposes,
        selectedState,
        allStates,
        selectedObservationStrategy,
        allObservationStrategies,
        observationIdSet,
        changeStrategy,
        localStoreKey,
        setState
    } = props
    return <div className="col-lg-3 col-md-3 col-sm-12">
        <div className='p-field p-grid'>
            {purposeFilter(selectedPurpose, allPurposes, localStoreKey, setState)}
            {stateFilter(selectedState, allStates, localStoreKey, setState)}
        </div>
        {strategySelector(selectedObservationStrategy, allObservationStrategies, observationIdSet, changeStrategy)}
    </div>
}

ObservationStrategySelector.propTypes = {
  selectedPurpose: PropTypes.any,
  allPurposes: PropTypes.any,
  selectedState: PropTypes.any,
  allStates: PropTypes.any,
  selectedObservationStrategy: PropTypes.any,
  allObservationStrategies: PropTypes.any,
  observationIdSet: PropTypes.any,
  changeStrategy: PropTypes.any,
  localStoreKey: PropTypes.any,
  setState: PropTypes.any
}