import {render,waitFor} from '@testing-library/react';
import ObservationStrategySelector, {
    optionTemplate,
    setObservationStrategyFilters
} from './ObservationStrategySelector';
import {clickItem, removeReact18ConsoleErrors, setMultiSelectValue} from "../../../utils/test.helper";
import UtilService from "../../../services/util.service";
import ScheduleService from "../../../services/schedule.service";

removeReact18ConsoleErrors();

const allObservationStrategies = [
    {id: 1, name: "Fist", value: "fist", purpose_value: "1", state_value: "1", version: 11, description: 'Hitting'},
    {id: 2, name: "Gun", value: "gun", purpose_value: "2", state_value: "3", version: 12, description: 'Shooting'},
    {id: 3, name: "Sword", value: "sword", purpose_value: "3", state_value: "2", version: 13, description: 'Slicing'},
];
const observationIdSet = [1, 2, 3];

describe('itemTemplate', () => {
    test.each([allObservationStrategies])('Renders the dropdown options correctly', (observationStrategy) => {
        const {getByTitle} = render(
            <div>{optionTemplate(observationStrategy, observationIdSet)}</div>
        );

        const renderedElement = getByTitle(observationStrategy.description);
        expect(renderedElement).toBeInTheDocument();
        const textContent = renderedElement.textContent;
        expect(textContent).toContain(observationStrategy.name)
        expect(textContent).toContain(observationStrategy.purpose_value)
        expect(textContent).toContain(observationStrategy.state_value)
        expect(textContent).toContain(`v${observationStrategy.version}`)
        expect(renderedElement).toHaveStyle(`font-weight: bold`);
    });

    test('Does not render the dropdown options when observationIdSet is not provided', () => {
        const {getByTitle} = render(<div>{optionTemplate(allObservationStrategies[0])}</div>);
        expect(() => getByTitle(allObservationStrategies[0].description)).toThrow()
    });

    const observationIdSets = [[], [4], [5, 6]];
    observationIdSets.forEach(observationIdSet => {
        test('Renders the dropdown option with normal fontWeight when option id is not in observationIdSet: ' + observationIdSet, () => {
            const {getByTitle} = render(<div>{optionTemplate(allObservationStrategies[0], observationIdSet)}</div>);
            const renderedElement = getByTitle(allObservationStrategies[0].description);
            expect(renderedElement).toHaveStyle(`font-weight: normal`);
        });
    })
});


describe('ObservationStrategySelector', () => {
    let content;
    const allPurposes = [{name: 'Head', value: '1'}, {name: 'Chest', value: '2'}, {name: 'Stomach', value: '3'}];
    const allStates = [{name: 'Low', value: '1'}, {name: 'Medium', value: '2'}, {name: 'High', value: '3'}];

    const observationOptionTemplate = <div></div>;
    const changeStrategy = jest.fn();
    const setState = jest.fn();
    let parentStateFields = {
        "observStrategies": [],
        "observStrategy": {},
        "observStrategyFilters": {states: ["active"]},
        "paramsSchema": null,
        "rowData": []
    }

    beforeEach(() => {
        content = render(
            <ObservationStrategySelector
                selectedPurpose={[allPurposes[0].value]}
                allPurposes={allPurposes}
                selectedState={[allStates[0].value]}
                allStates={allStates}
                selectedObservationStrategy={allObservationStrategies[0]}
                allObservationStrategies={allObservationStrategies}
                observationOptionTemplate={observationOptionTemplate}
                observationIdSet={observationIdSet}
                changeStrategy={changeStrategy}
                setState={setState}
            />
        )
    })

    test('Renders all elements correctly', () => {
        expect(content.getByTestId('strategy-purpose')).toBeInTheDocument();
        expect(content.getByTestId('strategy-state')).toBeInTheDocument();
        expect(content.getByTestId('observStrategy')).toBeInTheDocument();
    });

    test('calls setObservationStrategyFilters. First when state is changed, second when purpose is changed', async () => {
        const originalState = allStates[0];

        const additionalState = allStates[1];
        await setMultiSelectValue(content, "strategy-state", additionalState.name)

        //initial filter value (=states) is changed and the purpose filter is initialized
        parentStateFields.observStrategyFilters = {
            "purpose": [],
            "states": [originalState.value, additionalState.value]
        }
        waitFor( () => expect(setState).toHaveBeenCalledWith(parentStateFields));

        const originalPurpose = allPurposes[0];

        const additionalPurpose = allPurposes[1];
        await setMultiSelectValue(content, "strategy-purpose", additionalPurpose.name)
        //initial filter value (=states) is not changed when only purpose filter is set
        parentStateFields.observStrategyFilters = {
            ...{"purpose": [originalPurpose.value, additionalPurpose.value]},
            ...parentStateFields.observStrategyFilters
        }
        expect(setState).toHaveBeenCalledWith(parentStateFields);
    });

    test('calls changeStrategy when observation strategy is changed', async () => {
        const newStrategy = allObservationStrategies[1];

        await clickItem(content.getByTestId('observStrategy'))
        await clickItem(content.getByTitle(newStrategy.description))
        expect(changeStrategy).toHaveBeenCalledWith(newStrategy.id);
    });
})
;

describe('setObservationStrategyFilters', () => {
    let setStateMock, observStrategiesSpy, utilSpy;
    const localStoreKey = 'the-pride-lands'

    beforeEach(() => {
        utilSpy = jest.spyOn(UtilService, 'localStore').mockReturnValueOnce({});

        observStrategiesSpy = jest.spyOn(ScheduleService, 'getObservationStrategies').mockImplementation(() => {
            return Promise.resolve('mockedObservationStrategies')
        });

        setStateMock = jest.fn()
    })

    afterEach(() => {
        jest.clearAllMocks();
    });

    it('should set observation strategy filters for purpose', async () => {
        const selectedFilter = ['simba', 'nala'];
        const filterId = 'purpose';

        await setObservationStrategyFilters(selectedFilter, filterId, localStoreKey, setStateMock);

        expect(utilSpy).toHaveBeenCalledTimes(2); //get and set
        expect(observStrategiesSpy).toHaveBeenCalledWith(
            "state=active&purpose=simba&purpose=nala&"
        );

        expect(setStateMock).toHaveBeenCalledWith({
            observStrategyFilters: {
                states: ['active'],
                purpose: ['simba', 'nala'],
            },
            observStrategies: 'mockedObservationStrategies',
            paramsSchema: null,
            observStrategy: {},
            rowData: [],
        });
    });

    it('should set observation strategy filters for state', async () => {
        const selectedFilter = ['young', 'old'];
        const filterId = 'state';

        await setObservationStrategyFilters(selectedFilter, filterId, localStoreKey, setStateMock);

        expect(utilSpy).toHaveBeenCalledTimes(2); //get and set
        expect(observStrategiesSpy).toHaveBeenCalledWith(
            'state=young&state=old&',
        );

        expect(setStateMock).toHaveBeenCalledWith({
            observStrategyFilters: {
                states: ['young', 'old'],
                purpose: [],
            },
            observStrategies: 'mockedObservationStrategies',
            paramsSchema: null,
            observStrategy: {},
            rowData: [],
        });
    });

    it('Reset; called without filters', async () => {
        await setObservationStrategyFilters([], '', localStoreKey, setStateMock);

        expect(utilSpy).toHaveBeenCalledTimes(2); //get and set
        expect(observStrategiesSpy).toHaveBeenCalledWith(
            'state=active&',
        );

        expect(setStateMock).toHaveBeenCalledWith({
            observStrategyFilters: {
                states: ['active'],
                purpose: [],
            },
            observStrategies: 'mockedObservationStrategies',
            paramsSchema: null,
            observStrategy: {},
            rowData: [],
        });
    });

    it('Updating twice to test with local store', async () => {
        utilSpy
            .mockReturnValueOnce({}) //first call
            .mockReturnValueOnce({states: ['young', 'old'], purpose: []}); //second call

        let selectedFilter = ['young', 'old'];
        let filterId = 'state';

        await setObservationStrategyFilters(selectedFilter, filterId, localStoreKey, setStateMock);

        selectedFilter = ['simba', 'nala'];
        filterId = 'purpose';

        await setObservationStrategyFilters(selectedFilter, filterId, localStoreKey, setStateMock);

        expect(utilSpy).toHaveBeenNthCalledWith(1, {"key": localStoreKey, "type": "get"});
        expect(utilSpy).toHaveBeenNthCalledWith(2, {
            "key": localStoreKey, "type": "set", "value": {"purpose": [], "states": ["young", "old"]}
        });
        expect(utilSpy).toHaveBeenNthCalledWith(3, {"key": localStoreKey, "type": "get"});
        expect(utilSpy).toHaveBeenNthCalledWith(4, {
            "key": localStoreKey, "type": "set", "value": {"purpose": ['simba', 'nala'], "states": ["young", "old"]}
        });

        expect(observStrategiesSpy).toHaveBeenNthCalledWith(1, "state=young&state=old&");
        expect(observStrategiesSpy).toHaveBeenNthCalledWith(2, "state=young&state=old&purpose=simba&purpose=nala&");
        expect(setStateMock).toHaveBeenCalledWith({
            observStrategyFilters: {
                states: ['young', 'old'],
                purpose: ['simba', 'nala'],
            },
            observStrategies: 'mockedObservationStrategies',
            paramsSchema: null,
            observStrategy: {},
            rowData: [],
        });
    });
});