import PropTypes from 'prop-types';
import { useState, useEffect } from 'react';
import { ProgressBar } from 'primereact/progressbar';
import _ from 'lodash';
import TaskService from '../../services/task.service';
import ScheduleService from '../../services/schedule.service';


/**
 * Component to show the ingest progress.
 */
const IngestProgress = (props) => {
    const TASK_NOT_STARTED_STATUSES = ['defined', 'schedulable', 'scheduled', 'unschedulable'];
    const [ingestProgress, setIngestProgress] = useState(0);
    const expandFields = 'task_blueprints,task_blueprints.specifications_template,task_blueprints.subtasks';
    const fetchFields = ['task_blueprints.id', 'task_blueprints.status', 'task_blueprints.obsolete_since',
                            'task_blueprints.specifications_template.type_value', 'task_blueprints.subtasks.id', 
                            'task_blueprints.subtasks.primary'];

    useEffect(() => {
            getIngestCompleteness(props.schedulingUnitId, props.tasks);
    }, [ingestProgress]);

    /**
     * Gets the progress of the ingest subtask which is not obsolete and started. Sufficient to send one of the arguments.
     * @param {Number} schedulingUnitId - Scheduling Unit id for which the ingest task is to be identied and fetch the progress
     * @param {Array} tasks - List of task blueprints with subtasks
     */
    const getIngestCompleteness = async(schedulingUnitId, tasks) => {
        // If tasks are not passed get them and add custom properties
        if (!tasks) {
            let suBlueprint = await ScheduleService.getExpandedSchedulingUnit('blueprint', schedulingUnitId, expandFields, fetchFields.join(","));
            tasks = suBlueprint.task_blueprints;
        }
        _.map(tasks, task => {
            task.obsolete = task.obsolete_since!==null;
            task.subTaskID = (_.find(task.subtasks, subtask => subtask.primary === true)).id;
        });
        let ingestProgress = 0;
        // Filter only ingest tasks
        let ingestTasks = _.filter(tasks, taskBlueprint => {
            return taskBlueprint.specifications_template.type_value === "ingest";
        });
        // Filter ingest tasks which are not obsolete and status is after started and not canceled
        ingestTasks = _.filter(ingestTasks, ingestTask => !ingestTask.obsolete && !ingestTask.status=='cancelled' && TASK_NOT_STARTED_STATUSES.indexOf(ingestTask.status)<0) ;
        // If more than one ingest taks present, take the last one
        for (const ingestTask of ingestTasks) {
            let subtaskProgress = await TaskService.getSubtaskProgress(ingestTask.subTaskID);
            ingestProgress = subtaskProgress?subtaskProgress.progress*100:0;
        }
        // round to 2 decimals
        ingestProgress = Math.round(100*ingestProgress)/100;
        setIngestProgress(ingestProgress);
    };

    return (
        <ProgressBar value={ingestProgress}></ProgressBar>
    );
};

IngestProgress.propTypes = {
  schedulingUnitId: PropTypes.any,
  tasks: PropTypes.any
}

export default IngestProgress;