import { TabView, TabPanel } from "primereact/tabview";
import PropTypes from 'prop-types';
import PageHeader from "../../layout/components/PageHeader";
import UtilService from "../../services/util.service";
import { ListBox } from 'primereact/listbox';
import { useEffect, useState } from "react";
import StationGeoView from './StationGeoView'
import StationConstraintView from './StationConstraintView'
import moment from "moment";
import ScheduleService from "../../services/schedule.service";
import UIConstants from "../../utils/ui.constants";
import PageHeaderActions from "../../utils/pageheaderactions.util.js";

// see https://react-leaflet.js.org/docs/api-map/
export default function StationView(props) {
  const {
    location
  } = props

  const [isLoading, setIsLoading] = useState(true)
  const [stations, setStations] = useState()
  const [stationsGeo, setStationsGeo] = useState([])
  const [selectedStation, setSelectedStation] = useState("CS002")
  const [flatBluePrints, setFlatBluePrints] = useState()
  const [selectedBluePrint, setSelectedBluePrint] = useState()
  const [selectedBluePrintId, setSelectedBluePrintId] = useState()
  const [startTime, setStartTime] = useState(moment().startOf('day').toDate())
  const [endTime, setEndTime] = useState(moment().endOf('day').add(UIConstants.WEEKVIEW_SHOW_NUMBER_OF_DAYS, 'days').toDate())
  const [map, setMap] = useState()
  const isDebugLogging = false;

  async function fetchStations() {
    let stationlist = await UtilService.getStations();
    updateStations(stationlist);
  }

  function updateStations(stationlist) {
    if (stationlist === null) return;
    let flatstationList = Object.entries(stationlist)
    setStations(flatstationList);
    let geostations = MakeGeoJson(flatstationList);
    setStationsGeo(geostations);
  }



  function MakeGeoJson(stations) {
    let StationgeojsonArray = []
    for (let station in stations) {
      const geostationJson = generateGeoJson(station, stations[station]);
      StationgeojsonArray.push(geostationJson);
    }
    return StationgeojsonArray;
  }



  function GetFlatBluePrints() {
    return flatBluePrints;
  }

  function SetLogicalSelectedBluePrint(prints) {
    for (const element of prints) {
      if (element[1].status === "observing") {
        setSelectedBluePrint(element);
        return
      }
    }

    for (const element of prints) {
      if (element[1].status === "finished") {
        setSelectedBluePrint(element);
        return
      }
    }

    for (const element of prints) {
      if (element[1].status === "error") {
        setSelectedBluePrint(element);
        return
      }
    }

  }

  function MakeLabel(prints) {
    for (const element of prints) {
      const print = element;
      print[0] = print[1].name + " - " + print[1].id + " - " + print[1].status
    }
  }

  
  function MakeStationSelectionVisible(selectedBluePrint) {
    if (isDebugLogging) console.log("Current Stations", stations);
    const BluePrintNpde = selectedBluePrint[1];
    const specified_stations = BluePrintNpde.specified_stations;
    const used_stations = BluePrintNpde.used_stations;
    const missing_stations = BluePrintNpde.missing_stations;


    let existingstations=stations;

    for (let counter = 0; counter < existingstations.length; counter++) {
      const stationame = existingstations[counter][0];
      const isInSpecified = specified_stations.indexOf(stationame) > -1;
      const isInUSing = used_stations.indexOf(stationame) > -1;
      const isInMissing = missing_stations.indexOf(stationame) > -1;

      let className = ""
      if (isInSpecified) className = className + " specified_station ";
      if (isInUSing) className = className + " used_station ";
      if (isInMissing) className = className + " missed_station ";
      existingstations[counter][1].className = className
    }
    let geostations = MakeGeoJson(stations);
    setStationsGeo(geostations);
    
    setStations(existingstations);

  }

  useEffect(() => {
    if (selectedBluePrint?.[1]?.id) {
      console.log("Selected BluePrint", selectedBluePrint)
      MakeStationSelectionVisible(selectedBluePrint);
      setSelectedBluePrintId("" + selectedBluePrint[1].id)
    }
  }, [selectedBluePrint]);

  function SortBluePrints(prints) {
    return prints.sort((a, b) => {
      // Compare names
      if (a.name < b.name) {
        return -1;
      }
      if (a.name > b.name) {
        return 1;
      }
      // Names are equal
      return 0;
    });

  }

  async function fetchBluePrints() {
    setIsLoading(true);
    const from = moment(startTime).format(UIConstants.CALENDAR_DATETIME_FORMAT);
    const until = moment(endTime).format(UIConstants.CALENDAR_DATETIME_FORMAT);
    const schedulingUnits = await ScheduleService.getTimelineSlimBlueprints(from, until);
    let sortedbluePrints = SortBluePrints(schedulingUnits);
    let flattedBluePrints = Object.entries(sortedbluePrints)
    MakeLabel(flattedBluePrints);
    setFlatBluePrints(flattedBluePrints);
    SetLogicalSelectedBluePrint(flattedBluePrints);
    setIsLoading(false);
  }

  function getBluePrintActions() {
    return [
      PageHeaderActions.actionButtonObject(
        isLoading ? "System is already reloading the blueprint data" : "Reload the Blue print data",
        (isLoading ? "pi-spin pi-hourglass " : "pi-sync"),
        `subsystem subsystem--${isLoading ? "on" : "standard"}`,
        { callback: () => fetchBluePrints() }
      ),
      PageHeaderActions.actionDropDownObject("Blue print ", GetFlatBluePrints(),
        { callback: (blueprint) => setSelectedBluePrint(blueprint) },
        selectedBluePrint, "station-blueprint-dropdown", undefined, "0", "select Blue print"
      ),
      
    ]
  }

  function navigateToDay(addingDays) {
    let newStartTime = new Date(startTime);
    newStartTime.setDate(startTime.getDate() + addingDays);
    let NewEndTime = new Date(endTime)
    NewEndTime.setDate(endTime.getDate() + addingDays);
    setStartTime(newStartTime);
    setEndTime(NewEndTime);
  }


  function generateGeoJson(stationid, station) {
    let name = station[0];
    let longitude = station[1].longitude;
    let latitude = station[1].latitude;

    return {
      type: "Feature",
      properties: {
        name: name,
        version: station[1].version,
        className: station[1].className || ""
      },
      "geometry": {
        "type": "Point",
        "coordinates": [
          longitude,
          latitude
        ]
      },
      id: name
    }
  }




  function ZoomTo(station) {
    let longitude = station[1].longitude;
    let latitude = station[1].latitude;
    map?.setView([latitude, longitude], 14);
  }


  useEffect(() => {
    fetchStations();
    fetchBluePrints();
  }, []);


  function constrainsSelect(station) {
    console.log(station);
    setSelectedStation(...station)
  }

  const stationTemplate = (option) => {
    let classCombined = option?.[1]?.className || ""
    classCombined = classCombined + " flex align-items-center stationoption"
    return (
      <div className={classCombined} >{option[0]}</div>
    );
  };

  return <>

    <PageHeader location={location} title={'Stations - List '} actions={getBluePrintActions().concat(PageHeaderActions.getOneDayNavigationActions(navigateToDay, setStartTime, startTime))} className="defaultpageHeader" />
    <TabView className="TabNoScroll">
      <TabPanel header="Station Geo Map" className="TabStation">
        <div className="StationListWrap" >
          <ListBox options={stations} optionLabel="0" className="StationListbox" onChange={(e) => ZoomTo(e.value)} itemTemplate={stationTemplate}  emptyMessage="000" data-testid="stationlistbox" />
          <StationGeoView stations={stationsGeo} selected={selectedStation} mapRef={setMap} ></StationGeoView >
        </div>
      </TabPanel>
      <TabPanel header="Station Constraints Plot">
        <div className="StationListWrap" >
          <ListBox options={stations} optionLabel="0" className="StationListbox" onChange={(e) => constrainsSelect(e.value)} selected={selectedStation} itemTemplate={stationTemplate} emptyMessage="000" data-testid="stationlistboxconstraints" />
          <StationConstraintView station={selectedStation} stations={stations} selectedBluePrint={selectedBluePrint} selectedBluePrintId={selectedBluePrintId} startTime={moment(startTime).format(UIConstants.CALENDAR_DEFAULTDATE_FORMAT)}    ></StationConstraintView>
        </div>
      </TabPanel>
    </TabView>
  </>
}

StationView.propTypes = {
  location: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
  title: PropTypes.string
}