import { BrowserRouter as Router } from 'react-router-dom';
import { act } from "react-dom/test-utils";
import { render, cleanup, waitFor } from '@testing-library/react';
import '@testing-library/jest-dom';
import mockConsole from 'jest-mock-console';
import _ from 'lodash';

import { TaskView } from './view';
import TaskService from '../../services/task.service';
import TaskServiceMock from '../../__mocks__/task.service.data';
import AuthService from '../../services/auth.service';

import AuthServiceMock from '../../__mocks__/auth.service.data';

let taskPermissionSpy, taskFilterDefSpy, subtaskTypesSpy, taskDetailsSpy, taskTemplateSpy,
    schedulingUnitSpy;
let restoreConsole;

beforeEach(() => {
    restoreConsole = mockConsole();
    setMockSpy();
});

afterEach(() => {
    restoreConsole();
    // cleanup on exiting
    clearMockSpy();
    cleanup();
});

/**
 * To set mock spy for Services that have API calls to the back end to fetch data
 */
const setMockSpy = (() => {
    taskPermissionSpy = jest.spyOn(AuthService, 'getAccessControlMethod');
    taskPermissionSpy.mockImplementation((url) => {
        if (_.startsWith(url, "task_draft")) {
            return Promise.resolve(AuthServiceMock.task["1"]);
        } else if (_.startsWith(url, "task_blueprint")) {
            return Promise.resolve(AuthServiceMock.task_blueprint["9"]);
        } else if (_.startsWith(url, "subtask")) {
            return Promise.resolve(AuthServiceMock.subtask["2000011"]);
        }
    });
    taskFilterDefSpy = jest.spyOn(TaskService, 'getTaskFilterDefinition');
    taskFilterDefSpy.mockImplementation(() => { return Promise.resolve(TaskServiceMock.getTaskFilterDefinition) });
    subtaskTypesSpy = jest.spyOn(TaskService, 'getSubtaskType');
    subtaskTypesSpy.mockImplementation(() => { return Promise.resolve(TaskServiceMock.subTaskTypes) });
    taskDetailsSpy = jest.spyOn(TaskService, 'getTaskDetails');
    taskDetailsSpy.mockImplementation((taskType, taskId ) => {
        if (taskType === "draft") {
            return Promise.resolve(_.find(TaskServiceMock.taskDrafts, { "id": parseInt(taskId) }));
        } else {
            return Promise.resolve(_.find(TaskServiceMock.taskBlueprints, { "id": parseInt(taskId) }));
        }
    });
    taskTemplateSpy = jest.spyOn(TaskService, 'getTaskTemplate');
    taskTemplateSpy.mockImplementation((templateId) => {
        let template = _.find(TaskServiceMock.getTaskTemplates(), { "id": templateId });
        return Promise.resolve(template);
    });
    schedulingUnitSpy = jest.spyOn(TaskService, "getSchedulingUnit");
    schedulingUnitSpy.mockImplementation((type, id ) => {
        if (type === "draft") {
            return Promise.resolve(_.find(TaskServiceMock.schedulingUnitDrafts, { "id": id }));
        } else {
            return Promise.resolve(_.find(TaskServiceMock.schedulingUnitBlueprints, { "id": id }));
        }
    });
});

const clearMockSpy = (() => {
    taskPermissionSpy.mockRestore();
    taskFilterDefSpy.mockRestore();
    subtaskTypesSpy.mockRestore();
    taskDetailsSpy.mockRestore();
    taskTemplateSpy.mockRestore();
    schedulingUnitSpy.mockRestore();
});
describe('Task Renderers ', () => {
    it("renders Task details page", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "9", type: "draft" } }} history={{}} location="/task/view/draft/9" /></Router>);
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
    });



    it("test Combined Observation Task Draft view of IM LBA Survey - 3 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "9", type: "draft" } }} history={{}} location="/task/view/draft/9" key="CombinedTest" /></Router>);
            await new Promise((r) => setTimeout(r, 5000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Combined Observation")).toBeInTheDocument();
        expect(content.getByText("IM LBA Survey - 3 Beams")).toBeInTheDocument();
        expect(content.getByText("OOO.O Paaa+01 Paaa+02 Paaa+03")).toBeInTheDocument();
        expect(content.getByText("Calibrator Pipeline")).toBeInTheDocument();
        expect(content.getByText("Cleanup")).toBeInTheDocument();
        expect(content.getByText("Pipeline target3")).toBeInTheDocument();
        expect(content.getByText("Pipeline target2")).toBeInTheDocument();
        expect(content.getByText("Pipeline target1")).toBeInTheDocument();
        expect(content.getByText("parallel calibrator target observation")).toBeInTheDocument();
        await waitFor(() => expect(content.getByText("Auto-select")).toBeInTheDocument());
        await waitFor(() => expect(content.getByText("Auto-select")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument());
        await waitFor(() => expect(content.getAllByText("Reference frame").length).toBe(5));
        await waitFor(() => expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[duration]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByText("Storage cluster")).toBeInTheDocument());
        await waitFor(() => expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument());
        await waitFor(() => expect(content.getByText("Channels/subband")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle1]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle2]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][target]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][1][name]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][1][subbands]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][1][frequency]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle1]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle2]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][target]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][2][name]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][2][subbands]")).toBeInTheDocument());
        await waitFor(() => expect(content.getByLabelText("specification[station_configuration][SAPs][2][frequency]")).toBeInTheDocument());
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByText("Station groups")).toBeInTheDocument();
        expect(content.getByText("Station group 1")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByText("Station group 3")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
        expect(content.getByText("Do/Don't create plots from the QA file from the observation")).toBeInTheDocument();
        expect(content.getByText("Task Specification")).toBeInTheDocument();
    });



    it("test Combined Observation Task Draft view of IM LBA LoDSS - 5 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "1", type: "draft" } }} history={{}} location="/task/view/draft/1" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Combined Observation")).toBeInTheDocument();
        expect(content.getByText("IM LBA LoDSS - 5 Beams")).toBeInTheDocument();
        expect(content.getByText("oXXX Paaa+01 3Cabc")).toBeInTheDocument();
        expect(content.getByText("Calibrator Pipeline")).toBeInTheDocument();
        expect(content.getByText("Pipeline target5")).toBeInTheDocument();
        expect(content.getByText("Pipeline target4")).toBeInTheDocument();
        expect(content.getByText("Pipeline target3")).toBeInTheDocument();
        expect(content.getByText("Pipeline target2")).toBeInTheDocument();
        expect(content.getByText("Pipeline target1")).toBeInTheDocument();
        expect(content.getByText("parallel calibrator target observation")).toBeInTheDocument();
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(7);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getByText("Channels/subband")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByText("Station groups")).toBeInTheDocument();
        expect(content.getByText("Station group 1")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByText("Station group 3")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
        expect(content.getByText("Do/Don't create plots from the QA file from the observation")).toBeInTheDocument();
    });



    it("test Calibrator Pipeline Task Draft view of IM LBA LoDSS - 5 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "2", type: "draft" } }} history={{}} location="/task/view/draft/2" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Calibrator Pipeline")).toBeInTheDocument();
        expect(content.getByText("IM LBA LoDSS - 5 Beams")).toBeInTheDocument();
        expect(content.getByText("3Cabc/1.0/CP")).toBeInTheDocument();
        expect(content.getByText("preprocessing pipeline")).toBeInTheDocument();
        expect(content.getByText("Combined Observation")).toBeInTheDocument();
        expect(content.getByText("Ingest")).toBeInTheDocument();

        expect(content.getByLabelText("specification[average][time_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByText("CasA")).toBeInTheDocument();
        expect(content.getByText("CygA")).toBeInTheDocument();
        expect(content.getByText("HerA")).toBeInTheDocument();
        expect(content.getByText("HydraA")).toBeInTheDocument();
        expect(content.getByText("TauA")).toBeInTheDocument();
        expect(content.getByText("VirA")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][time_steps]")).toBeInTheDocument();
        expect(content.getByText("Ignore target")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][frequency_steps]")).toBeInTheDocument();
        expect(content.getByText("RFI flagging strategy")).toBeInTheDocument();
        expect(content.getByText("Flag outer channels")).toBeInTheDocument();
        expect(content.getByText("Flag auto correlations")).toBeInTheDocument();
        expect(content.getByText("Storage Manager")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
        expect(content.getByText("Task Specification")).toBeInTheDocument();
    });

    it("test Target Pipeline Task Draft view of IM LBA LoDSS - 5 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "7", type: "draft" } }} history={{}} location="/task/view/draft/7" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Pipeline target1")).toBeInTheDocument();
        expect(content.getByText("IM LBA LoDSS - 5 Beams")).toBeInTheDocument();
        expect(content.getByText("Paaa+01/1.0/PP")).toBeInTheDocument();
        expect(content.getByText("preprocessing pipeline")).toBeInTheDocument();
        expect(content.getByText("Combined Observation")).toBeInTheDocument();
        expect(content.getByText("Ingest")).toBeInTheDocument();
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByText("CasA")).toBeInTheDocument();
        expect(content.getByText("CygA")).toBeInTheDocument();
        expect(content.getByText("HerA")).toBeInTheDocument();
        expect(content.getByText("HydraA")).toBeInTheDocument();
        expect(content.getByText("TauA")).toBeInTheDocument();
        expect(content.getByText("VirA")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][time_steps]")).toBeInTheDocument();
        expect(content.getByText("Ignore target")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][frequency_steps]")).toBeInTheDocument();
        expect(content.getByText("RFI flagging strategy")).toBeInTheDocument();

        expect(content.getByText("Flag outer channels")).toBeInTheDocument();

        expect(content.getByText("Flag auto correlations")).toBeInTheDocument();

        expect(content.getByText("Storage Manager")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
    });

    it("test IM BF Cal Tgt Task Draft view", async () => {
        let content;
        await act(async () => {
            try {
            content = render(<Router><TaskView match={{ params: { id: "68", type: "draft" } }} history={{}} location="/task/view/draft/68" /></Router>);
            }
            catch (ex)
            {
                console.log(ex);
            }
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("IM BF Cal&Tgt")).toBeInTheDocument();
        expect(content.getByText("Observation")).toBeInTheDocument();
        expect(content.getByText("parallel calibrator target and beamforming observation")).toBeInTheDocument();
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();

        expect(content.getByText("Beamformer")).toBeInTheDocument();
        expect(content.getByText("Pipelines")).toBeInTheDocument();

        expect(content.getByText("Coherent Tied-Array Beams")).toBeInTheDocument();
        expect(content.getAllByText("SAPs").length).toBe(3);
        expect(content.getAllByText("Output quantisation settings").length).toBe(3);
        expect(content.getAllByText("Bits/sample").length).toBe(3);
        expect(content.getAllByText("Output quantisation into integers").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getAllByText("Stokes").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getAllByText("Channels/subband").length).toBe(4);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByText("Enable Fly's Eye")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByText("Incoherent Tied-Array Beams")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[beamformer][pipelines][0][name]")).toBeInTheDocument();
        expect(content.getAllByText("Station groups").length).toBe(2);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Use PPF when beamforming")).toBeInTheDocument();


        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();

        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();

        expect(content.getByText("File Conversion")).toBeInTheDocument();
        expect(content.getByText("Do/Don't create a QA file for the observation")).toBeInTheDocument();
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_timestamps]")).toBeInTheDocument();

        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
        expect(content.getByText("Do/Don't create plots from the QA file from the observation")).toBeInTheDocument();
    });
    it("test Simple Beamforming Observation Task Draft view", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "53", type: "draft" } }} history={{}} location="/task/view/draft/53" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Simple Beamforming Observation")).toBeInTheDocument();
        expect(content.getByText("Observation")).toBeInTheDocument();
        expect(content.getByText("beamforming observation")).toBeInTheDocument();
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();

        expect(content.getByText("Beamformer")).toBeInTheDocument();
        expect(content.getByText("Pipelines")).toBeInTheDocument();

        expect(content.getByText("Coherent Tied-Array Beams")).toBeInTheDocument();
        expect(content.getAllByText("SAPs").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][subbands][list]")).toBeInTheDocument();
        expect(content.getAllByText("Method").length).toBe(1);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][count]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][width]")).toBeInTheDocument();
        expect(content.getByText("Allow after previous")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][pointing][target]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByText("Relative to SAP")).toBeInTheDocument();
        expect(content.getAllByText("Output quantisation settings").length).toBe(3);
        expect(content.getAllByText("Bits/sample").length).toBe(3);
        expect(content.getAllByText("Output quantisation into integers").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getAllByText("Stokes").length).toBe(3);

        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getAllByText("Channels/subband").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByText("Enable Fly's Eye")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByText("Incoherent Tied-Array Beams")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[beamformer][pipelines][0][name]")).toBeInTheDocument();
        expect(content.getAllByText("Station groups").length).toBe(2);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Use PPF when beamforming")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();

        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
    });

    it("test Target Observation Task Draft vew of IM HBA LoTSS - 2 Beams strategy", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "23", type: "draft" } }} history={{}} location="/task/view/draft/23" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        // checking Task details and specification 
        expect(content.getByText('Target Observation')).toBeInTheDocument();
        expect(content.getByText('IM HBA LoTSS - 2 Beams')).toBeInTheDocument();
        expect(content.getByText('Paaa+01 & Paaa+02')).toBeInTheDocument();
        expect(content.getByText('Pipeline target2')).toBeInTheDocument();
        expect(content.getByText('Pipeline target1')).toBeInTheDocument();
        expect(content.getByText("target observation")).toBeInTheDocument();

        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getByText("Channels/subband")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][target]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][1][name]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][1][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][frequency]")).toBeInTheDocument();

        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByText("Station group 1")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][1][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Station group 3")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][2][max_nr_missing]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();

        expect(content.getAllByText("enabled").length).toBe(2);
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_timestamps]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
    });

    it("test Calibrator Observation Task Draft vew of IM HBA LoTSS - 2 Beams strategy", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "21", type: "draft" } }} history={{}} location="/task/view/draft/21" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        // checking Task details and specification 
        expect(content.getByText('Calibrator Observation 1')).toBeInTheDocument();
        expect(content.getByText('Calibrator Observation 1. Before the Target Observation')).toBeInTheDocument();
        expect(content.getByText('IM HBA LoTSS - 2 Beams')).toBeInTheDocument();
        expect(content.getByText('Cal1 3Cabc')).toBeInTheDocument();
        expect(content.getByText('Calibrator Pipeline 1')).toBeInTheDocument();
        expect(content.getByText("calibrator observation")).toBeInTheDocument();

        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(1);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
    });

    it("test Calibrator Pipeline Task Draft view of IM HBA LoTSS - 2 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "22", type: "draft" } }} history={{}} location="/task/view/draft/22" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Calibrator Pipeline 1")).toBeInTheDocument();
        expect(content.getByText("IM HBA LoTSS - 2 Beams")).toBeInTheDocument();
        expect(content.getByText("Cal1 3Cabc/PP")).toBeInTheDocument();
        expect(content.getByText("preprocessing pipeline")).toBeInTheDocument();
        expect(content.getByText("Calibrator Observation 1")).toBeInTheDocument();
        expect(content.getByText("Ingest")).toBeInTheDocument();
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByText("CasA")).toBeInTheDocument();
        expect(content.getByText("CygA")).toBeInTheDocument();
        expect(content.getByText("HerA")).toBeInTheDocument();
        expect(content.getByText("HydraA")).toBeInTheDocument();
        expect(content.getByText("TauA")).toBeInTheDocument();
        expect(content.getByText("VirA")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][time_steps]")).toBeInTheDocument();
        expect(content.getByText("Ignore target")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][frequency_steps]")).toBeInTheDocument();
        expect(content.getByText("RFI flagging strategy")).toBeInTheDocument();
        expect(content.getByText("Flag outer channels")).toBeInTheDocument();
        expect(content.getByText("Flag auto correlations")).toBeInTheDocument();
        expect(content.getByText("Storage Manager")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
    });

    it("test Pulsar Pipeline Task Draft view", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "50", type: "draft" } }} history={{}} location="/task/view/draft/50" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Pipeline")).toBeInTheDocument();
        expect(content.getByText("BF Pulsar Timing")).toBeInTheDocument();
        expect(content.getByText("Ingest")).toBeInTheDocument();
        expect(content.getByText("Cleanup")).toBeInTheDocument();
        expect(content.getByText("pulsar pipeline")).toBeInTheDocument();
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[dspsr][digifil][dm]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[dspsr][digifil][channels_per_part]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[dspsr][digifil][integration_time_factor]")).toBeInTheDocument();

        expect(content.getAllByText("Coherent Dedispersion").length).toBe(2);
        expect(content.getAllByText("Enabled").length).toBe(5);
        expect(content.getByLabelText("specification[dspsr][filterbank][channels_per_part]")).toBeInTheDocument();
        expect(content.getByText("RFI excision")).toBeInTheDocument();
        expect(content.getByText("Optimise period & DM")).toBeInTheDocument();
        expect(content.getByLabelText("specification[dspsr][subintegration_length]")).toBeInTheDocument();
        expect(content.getByText("Single pulse subintegration")).toBeInTheDocument();
        expect(content.getByLabelText("specification[output][quantisation][scale]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[output][dynamic_spectrum][time_average]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[presto][input][nr_blocks]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][input][decode_sigma]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][input][samples_per_block]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][rrats][dm_range]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][rfifind][blocks]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][prepdata][dm]")).toBeInTheDocument();
        expect(content.getByText("Enable prepfold")).toBeInTheDocument();
        expect(content.getByText("Fold")).toBeInTheDocument();

        expect(content.getByLabelText("specification[pulsar][name]")).toBeInTheDocument();
        expect(content.getByText("Strategy")).toBeInTheDocument();

        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
        expect(content.getByText("Single-pulse search")).toBeInTheDocument();
    });

    it("test Combined Observation Task Blueprint view of IM LBA Survey - 3 Beams", async () => {
        jest.setTimeout(120000)
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "9", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/9" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getAllByText("Combined Observation").length).toBe(2);
        expect(content.getByText("IM LBA Survey - 3 Beams")).toBeInTheDocument();
        expect(content.getByText("OOO.O Paaa+01 Paaa+02 Paaa+03")).toBeInTheDocument();
        expect(content.getByText("Calibrator Pipeline")).toBeInTheDocument();
        expect(content.getAllByText("Cleanup").length).toBe(2);
        expect(content.getByText("Pipeline target3")).toBeInTheDocument();
        expect(content.getByText("Pipeline target2")).toBeInTheDocument();
        expect(content.getByText("Pipeline target1")).toBeInTheDocument();
        expect(content.getByText("parallel calibrator target observation")).toBeInTheDocument();
        expect(content.getByText("Observation Start Time")).toBeInTheDocument();
        expect(content.getByText("Observation End Time")).toBeInTheDocument();
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(4);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(5);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getByText("Channels/subband")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByText("Station groups")).toBeInTheDocument();
        expect(content.getByText("Station group 1")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByText("Station group 3")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
        expect(content.getByText("Do/Don't create plots from the QA file from the observation")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
    });

    it("test Combined Observation Task Blueprint view of IM LBA LoDSS - 5 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "1", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/1" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getAllByText("Combined Observation").length).toBe(2);
        expect(content.getByText("IM LBA LoDSS - 5 Beams")).toBeInTheDocument();
        expect(content.getByText("oXXX Paaa+01 3Cabc")).toBeInTheDocument();
        expect(content.getByText("Calibrator Pipeline")).toBeInTheDocument();
        expect(content.getByText("Pipeline target5")).toBeInTheDocument();
        expect(content.getByText("Pipeline target4")).toBeInTheDocument();
        expect(content.getByText("Pipeline target3")).toBeInTheDocument();
        expect(content.getByText("Pipeline target2")).toBeInTheDocument();
        expect(content.getByText("Pipeline target1")).toBeInTheDocument();
        expect(content.getByText("parallel calibrator target observation")).toBeInTheDocument();
        expect(content.getByText("Observation Start Time")).toBeInTheDocument();
        expect(content.getByText("Observation End Time")).toBeInTheDocument();
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(4);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(7);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getByText("Channels/subband")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][2][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][3][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][4][frequency]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByText("Station groups")).toBeInTheDocument();
        expect(content.getByText("Station group 1")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByText("Station group 3")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
        expect(content.getByText("Do/Don't create plots from the QA file from the observation")).toBeInTheDocument();
    });

    it("test Calibrator Pipeline Task Blueprint view of IM LBA LoDSS - 5 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "2", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/draft/blueprint" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getAllByText("Calibrator Pipeline").length).toBe(2);
        expect(content.getByText("IM LBA LoDSS - 5 Beams")).toBeInTheDocument();
        expect(content.getByText("3Cabc/1.0/CP")).toBeInTheDocument();
        expect(content.getByText("preprocessing pipeline")).toBeInTheDocument();
        expect(content.getByText("Combined Observation")).toBeInTheDocument();
        expect(content.getAllByText("Ingest").length).toBe(2);
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(2);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByText("CasA")).toBeInTheDocument();
        expect(content.getByText("CygA")).toBeInTheDocument();
        expect(content.getByText("HerA")).toBeInTheDocument();
        expect(content.getByText("HydraA")).toBeInTheDocument();
        expect(content.getByText("TauA")).toBeInTheDocument();
        expect(content.getByText("VirA")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][time_steps]")).toBeInTheDocument();
        expect(content.getByText("Ignore target")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][frequency_steps]")).toBeInTheDocument();
        expect(content.getByText("RFI flagging strategy")).toBeInTheDocument();
        expect(content.getByText("Flag outer channels")).toBeInTheDocument();
        expect(content.getByText("Flag auto correlations")).toBeInTheDocument();
        expect(content.getByText("Storage Manager")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
    });

    it("test Target Pipeline Task Blueprint view of IM LBA LoDSS - 5 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "7", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/7" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getAllByText("Pipeline target1").length).toBe(2);
        expect(content.getByText("IM LBA LoDSS - 5 Beams")).toBeInTheDocument();
        expect(content.getByText("Paaa+01/1.0/PP")).toBeInTheDocument();
        expect(content.getByText("preprocessing pipeline")).toBeInTheDocument();
        expect(content.getByText("Combined Observation")).toBeInTheDocument();
        expect(content.getAllByText("Ingest").length).toBe(2);
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(2);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByText("CasA")).toBeInTheDocument();
        expect(content.getByText("CygA")).toBeInTheDocument();
        expect(content.getByText("HerA")).toBeInTheDocument();
        expect(content.getByText("HydraA")).toBeInTheDocument();
        expect(content.getByText("TauA")).toBeInTheDocument();
        expect(content.getByText("VirA")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][time_steps]")).toBeInTheDocument();
        expect(content.getByText("Ignore target")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][frequency_steps]")).toBeInTheDocument();
        expect(content.getByText("RFI flagging strategy")).toBeInTheDocument();
        expect(content.getByText("Flag outer channels")).toBeInTheDocument();
        expect(content.getByText("Flag auto correlations")).toBeInTheDocument();
        expect(content.getByText("Storage Manager")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
    });


        it("test IM BF Cal Tgt Task Blueprint view", async () => {
            let content;
            await act(async () => {
                content = render(<Router><TaskView match={{ params: { id: "68", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/68" /></Router>);
                await new Promise((r) => setTimeout(r, 2000));
            });
            expect(content.getByText("Task - Details")).toBeInTheDocument();
            expect(content.getByText("IM BF Cal&Tgt")).toBeInTheDocument();
            expect(content.getAllByText("Observation").length).toBe(3);
            expect(content.getByText("parallel calibrator target and beamforming observation")).toBeInTheDocument();
            expect(content.getAllByText("Observation Start Time").length).toBe(1);
            expect(content.getAllByText("Observation End Time").length).toBe(1);
            expect(content.getAllByText("Process Start Time").length).toBe(2);
            expect(content.getAllByText("Process End Time").length).toBe(2);
            expect(content.getByText("Status")).toBeInTheDocument();
            expect(content.getAllByRole("tablehead").length).toBe(13);
            expect(content.getAllByRole("row").length).toBe(4);
            expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
            expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        
            expect(content.getByText("Task Specification")).toBeInTheDocument();
            expect(content.getByText("Auto-select")).toBeInTheDocument();
            expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
            expect(content.getAllByText("Reference frame").length).toBe(3);
            expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        
            expect(content.getByText("Beamformer")).toBeInTheDocument();
            expect(content.getByText("Pipelines")).toBeInTheDocument();
        
            expect(content.getByText("Coherent Tied-Array Beams")).toBeInTheDocument();
            expect(content.getAllByText("SAPs").length).toBe(3);
            expect(content.getAllByText("Output quantisation settings").length).toBe(3);
            expect(content.getAllByText("Bits/sample").length).toBe(3);
            expect(content.getAllByText("Output quantisation into integers").length).toBe(3);
            expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_max]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_min]")).toBeInTheDocument();
            expect(content.getAllByText("Stokes").length).toBe(3);
            expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][subbands_per_file]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_integration_factor]")).toBeInTheDocument();
            expect(content.getAllByText("Channels/subband").length).toBe(4);
            expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][frequency_resolution]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_resolution]")).toBeInTheDocument();
        
            expect(content.getByText("Enable Fly's Eye")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_max]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_min]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][subbands_per_file]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_integration_factor]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][frequency_resolution]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_resolution]")).toBeInTheDocument();
        
            expect(content.getByText("Incoherent Tied-Array Beams")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_max]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_min]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][subbands_per_file]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_integration_factor]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][frequency_resolution]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_resolution]")).toBeInTheDocument();
        
            expect(content.getByLabelText("specification[beamformer][pipelines][0][name]")).toBeInTheDocument();
            expect(content.getAllByText("Station groups").length).toBe(2);
            expect(content.getByLabelText("specification[beamformer][pipelines][0][station_groups][0][max_nr_missing]")).toBeInTheDocument();
            expect(content.getByText("Use PPF when beamforming")).toBeInTheDocument();
        
        
            expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
            expect(content.getByText("Storage cluster")).toBeInTheDocument();
            expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
            expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();
        
            expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();
        
            expect(content.getByText("Antenna set")).toBeInTheDocument();
            expect(content.getByText("Band-pass filter")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        
            expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
        
            expect(content.getByText("File Conversion")).toBeInTheDocument();
            expect(content.getByText("Do/Don't create a QA file for the observation")).toBeInTheDocument();
            expect(content.getByLabelText("specification[QA][file_conversion][nr_of_subbands]")).toBeInTheDocument();
            expect(content.getByLabelText("specification[QA][file_conversion][nr_of_timestamps]")).toBeInTheDocument();
        
            expect(content.getByText("Inspection Plots")).toBeInTheDocument();
            expect(content.getByText("autocorrelation")).toBeInTheDocument();
            expect(content.getByText("crosscorrelation")).toBeInTheDocument();
            expect(content.getByText("Do/Don't create plots from the QA file from the observation")).toBeInTheDocument();
        });

    it("test Simple Beamforming Observation Task Blueprint view", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "53", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/53" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getByText("Simple Beamforming Observation")).toBeInTheDocument();
        expect(content.getAllByText("Observation").length).toBe(3);
        expect(content.getByText("beamforming observation")).toBeInTheDocument();
        expect(content.getAllByText("Observation Start Time").length).toBe(1);
        expect(content.getAllByText("Observation End Time").length).toBe(1);
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(2);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);

        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();

        expect(content.getByText("Beamformer")).toBeInTheDocument();
        expect(content.getByText("Pipelines")).toBeInTheDocument();

        expect(content.getByText("Coherent Tied-Array Beams")).toBeInTheDocument();
        expect(content.getAllByText("SAPs").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][subbands][list]")).toBeInTheDocument();
        expect(content.getAllByText("Method").length).toBe(1);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][count]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][width]")).toBeInTheDocument();
        expect(content.getByText("Allow after previous")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][pointing][angle1]")).toBeInTheDocument();
        const angle1El = content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][pointing][angle1]");
        expect(angle1El.value).toBe('03h06m00s');
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tabs][0][pointing][target]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByText("Relative to SAP")).toBeInTheDocument();
        expect(content.getAllByText("Output quantisation settings").length).toBe(3);
        expect(content.getAllByText("Bits/sample").length).toBe(3);
        expect(content.getAllByText("Output quantisation into integers").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getAllByText("Stokes").length).toBe(3);

        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getAllByText("Channels/subband").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByText("Enable Fly's Eye")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByText("Incoherent Tied-Array Beams")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_resolution]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[beamformer][pipelines][0][name]")).toBeInTheDocument();
        expect(content.getAllByText("Station groups").length).toBe(2);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Use PPF when beamforming")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();

        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
    });

    it("test Target Observation Task Blueprint vew of IM HBA LoTSS - 2 Beams strategy", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "24", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/24" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        // checking Task details and specification 
        expect(content.getAllByText('Target Observation').length).toBe(2);
        expect(content.getByText('IM HBA LoTSS - 2 Beams')).toBeInTheDocument();
        expect(content.getByText('Paaa+01 & Paaa+02')).toBeInTheDocument();
        expect(content.getByText('Pipeline target2')).toBeInTheDocument();
        expect(content.getByText('Pipeline target1')).toBeInTheDocument();
        expect(content.getByText("target observation")).toBeInTheDocument();
        expect(content.getByText("Observation Start Time")).toBeInTheDocument();
        expect(content.getByText("Observation End Time")).toBeInTheDocument();
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(4);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        expect(content.getByText("Task Specification")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getByText("Channels/subband")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][digital_pointing][target]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][1][name]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][SAPs][1][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][1][frequency]")).toBeInTheDocument();

        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getByText("Station group 1")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][1][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Station group 3")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][2][max_nr_missing]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();

        expect(content.getAllByText("enabled").length).toBe(2);
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_timestamps]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
    });

    it("test Calibrator Observation Task Blueprint vew of IM HBA LoTSS - 2 Beams strategy", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "22", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/22" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        // checking Task details and specification 
        expect(content.getAllByText('Calibrator Observation 1').length).toBe(2);
        expect(content.getByText('Calibrator Observation 1. Before the Target Observation')).toBeInTheDocument();
        expect(content.getByText('IM HBA LoTSS - 2 Beams')).toBeInTheDocument();
        expect(content.getByText('Cal1 3Cabc')).toBeInTheDocument();
        expect(content.getByText('Calibrator Pipeline 1')).toBeInTheDocument();
        expect(content.getByText("calibrator observation")).toBeInTheDocument();
        expect(content.getByText("Observation Start Time")).toBeInTheDocument();
        expect(content.getByText("Observation End Time")).toBeInTheDocument();
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(4);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(1);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
    });

    it("test Calibrator Pipeline Task Blueprint view of IM HBA LoTSS - 2 Beams", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "23", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/23" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getAllByText("Calibrator Pipeline 1").length).toBe(2);
        expect(content.getByText("IM HBA LoTSS - 2 Beams")).toBeInTheDocument();
        expect(content.getByText("Cal1 3Cabc/PP")).toBeInTheDocument();
        expect(content.getByText("preprocessing pipeline")).toBeInTheDocument();
        expect(content.getByText("Calibrator Observation 1")).toBeInTheDocument();
        expect(content.getAllByText("Ingest").length).toBe(2);
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(2);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);

        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByLabelText("specification[average][time_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_steps]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[average][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByText("CasA")).toBeInTheDocument();
        expect(content.getByText("CygA")).toBeInTheDocument();
        expect(content.getByText("HerA")).toBeInTheDocument();
        expect(content.getByText("HydraA")).toBeInTheDocument();
        expect(content.getByText("TauA")).toBeInTheDocument();
        expect(content.getByText("VirA")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][time_steps]")).toBeInTheDocument();
        expect(content.getByText("Ignore target")).toBeInTheDocument();
        expect(content.getByLabelText("specification[demix][frequency_steps]")).toBeInTheDocument();
        expect(content.getByText("RFI flagging strategy")).toBeInTheDocument();
        expect(content.getByText("Flag outer channels")).toBeInTheDocument();
        expect(content.getByText("Flag auto correlations")).toBeInTheDocument();
        expect(content.getByText("Storage Manager")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
    });

    it("test Pulsar Pipeline Task Blueprint view", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "50", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/50" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        expect(content.getAllByText("Pipeline").length).toBe(3);
        expect(content.getByText("BF Pulsar Timing")).toBeInTheDocument();
        expect(content.getAllByText("Ingest").length).toBe(2);
        expect(content.getAllByText("Cleanup").length).toBe(2);
        expect(content.getByText("pulsar pipeline")).toBeInTheDocument();
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(2);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByLabelText("specification[dspsr][digifil][dm]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[dspsr][digifil][channels_per_part]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[dspsr][digifil][integration_time_factor]")).toBeInTheDocument();

        expect(content.getAllByText("Coherent Dedispersion").length).toBe(2);
        expect(content.getAllByText("Enabled").length).toBe(5);
        expect(content.getByLabelText("specification[dspsr][filterbank][channels_per_part]")).toBeInTheDocument();
        expect(content.getByText("RFI excision")).toBeInTheDocument();
        expect(content.getByText("Optimise period & DM")).toBeInTheDocument();
        expect(content.getByLabelText("specification[dspsr][subintegration_length]")).toBeInTheDocument();
        expect(content.getByText("Single pulse subintegration")).toBeInTheDocument();
        expect(content.getByLabelText("specification[output][quantisation][scale]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[output][dynamic_spectrum][time_average]")).toBeInTheDocument();

        expect(content.getByLabelText("specification[presto][input][nr_blocks]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][input][decode_sigma]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][input][samples_per_block]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][rrats][dm_range]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][rfifind][blocks]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[presto][prepdata][dm]")).toBeInTheDocument();
        expect(content.getByText("Enable prepfold")).toBeInTheDocument();
        expect(content.getByText("Fold")).toBeInTheDocument();

        expect(content.getByLabelText("specification[pulsar][name]")).toBeInTheDocument();
        expect(content.getByText("Strategy")).toBeInTheDocument();

        expect(content.getByLabelText("specification[cluster_resources][cores_per_task]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[cluster_resources][parallel_tasks]")).toBeInTheDocument();
        expect(content.getByText("Cluster")).toBeInTheDocument();
        expect(content.getByText("Partition")).toBeInTheDocument();
        expect(content.getByText("Single-pulse search")).toBeInTheDocument();
    });

    it("test IM+BF Observation Task Draft vew of Solar Campaign strategy", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "69", type: "draft" } }} history={{}} location="/task/view/draft/69" /></Router>);
            await new Promise((r) => setTimeout(r, 2000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        // checking Task details and specification 
        expect(content.getAllByText("IM+BF").length).toBe(2);
        expect(content.getByText('IM+BF Observation')).toBeInTheDocument();
        expect(content.getByText("parallel calibrator target and beamforming observation")).toBeInTheDocument();
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument(), { timeout: 2000 });
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][subbands][list]")).toBeInTheDocument();
        expect(content.getAllByText("Method").length).toBe(1);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][count]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][width]")).toBeInTheDocument();
        expect(content.getByText("Tied-Array Beams")).toBeInTheDocument();
        expect(content.getAllByText("Bits/sample").length).toBe(3);
        expect(content.getAllByText("Output quantisation into integers").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getAllByText("Stokes").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getAllByText("Channels/subband").length).toBe(4);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_resolution]")).toBeInTheDocument();
        expect(content.getByText("Fly's Eye Settings")).toBeInTheDocument();
        expect(content.getByText("Enable Fly's Eye")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_resolution]")).toBeInTheDocument();
        expect(content.getAllByText("settings").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][name]")).toBeInTheDocument();
        expect(content.getAllByText("Station group 1").length).toBe(2);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Use PPF when beamforming")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getAllByText("Channels/subband").length).toBe(4);
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();
        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getAllByText("Station group 1").length).toBe(2);
        expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][1][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
        expect(content.getAllByText("enabled").length).toBe(2);
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_timestamps]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
    });

    it("test IM+BF Observation Task Blueprint vew of IM Solar Campaign strategy", async () => {

        jest.setTimeout(120000);
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "69", type: "blueprint" } }} history={{}} isUnitTest={true} location="/task/view/blueprint/69" /></Router>);
            await new Promise((r) => setTimeout(r, 500));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        // checking Task details and specification 
        expect(content.getAllByText('IM+BF').length).toBe(3);
        expect(content.getByText('IM+BF Observation')).toBeInTheDocument();
        expect(content.getByText("Observation Start Time")).toBeInTheDocument();
        expect(content.getByText("Observation End Time")).toBeInTheDocument();
        expect(content.getAllByText("Process Start Time").length).toBe(2);
        expect(content.getAllByText("Process End Time").length).toBe(2);
        expect(content.getByText("Status")).toBeInTheDocument();
        expect(content.getAllByRole("tablehead").length).toBe(13);
        expect(content.getAllByRole("row").length).toBe(2);
        expect(content.getByTitle("Cancel Subtasks")).toBeInTheDocument();
        expect(content.getAllByTitle("Mark as Obsolete").length).toBe(1);
        await waitFor(() => expect(content.getByText("Task Specification")).toBeInTheDocument());
        expect(content.getByLabelText("specification[duration]")).toBeInTheDocument();
        expect(content.getByText("Auto-select")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[calibrator][pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByLabelText("specification[calibrator][pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][subbands][list]")).toBeInTheDocument();
        expect(content.getAllByText("Method").length).toBe(1);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][count]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][SAPs][0][tab_rings][width]")).toBeInTheDocument();
        expect(content.getByText("Tied-Array Beams")).toBeInTheDocument();
        expect(content.getAllByText("Bits/sample").length).toBe(3);
        expect(content.getAllByText("Output quantisation into integers").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getAllByText("Stokes").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getAllByText("Channels/subband").length).toBe(4);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][coherent][settings][time_resolution]")).toBeInTheDocument();
        expect(content.getByText("Fly's Eye Settings")).toBeInTheDocument();
        expect(content.getByText("Enable Fly's Eye")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][flys eye][settings][time_resolution]")).toBeInTheDocument();
        expect(content.getAllByText("settings").length).toBe(3);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_max]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][quantisation][scale_min]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][subbands_per_file]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][incoherent][settings][time_integration_factor]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[beamformer][pipelines][0][name]")).toBeInTheDocument();
        expect(content.getAllByText("Station group 1").length).toBe(2);
        expect(content.getByLabelText("specification[beamformer][pipelines][0][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Use PPF when beamforming")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][integration_time]")).toBeInTheDocument();
        expect(content.getByText("Storage cluster")).toBeInTheDocument();
        expect(content.getByText("Topocentric Frequency Correction")).toBeInTheDocument();
        expect(content.getAllByText("Channels/subband").length).toBe(4);
        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][angle2]")).toBeInTheDocument();
        expect(content.getAllByText("Reference frame").length).toBe(3);
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][digital_pointing][target]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][name]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();
        expect(content.getByText("Antenna set")).toBeInTheDocument();
        expect(content.getByText("Band-pass filter")).toBeInTheDocument();
        expect(content.getAllByText("Station group 1").length).toBe(2);
        expect(content.getByLabelText("specification[station_configuration][station_groups][0][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByText("Station group 2")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][station_groups][1][max_nr_missing]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle1]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][angle2]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[station_configuration][tile_beam][target]")).toBeInTheDocument();
        expect(content.getAllByText("enabled").length).toBe(2);
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_subbands]")).toBeInTheDocument();
        expect(content.getByLabelText("specification[QA][file_conversion][nr_of_timestamps]")).toBeInTheDocument();
        expect(content.getByText("Inspection Plots")).toBeInTheDocument();
        expect(content.getByText("autocorrelation")).toBeInTheDocument();
        expect(content.getByText("crosscorrelation")).toBeInTheDocument();
    });
});
describe('Jeditor', () => {
    it("Checking Correctness of Custom fields in JEditor using Simple Observation draft", async () => {
        let content;
        await act(async () => {
            content = render(<Router><TaskView match={{ params: { id: "70", type: "draft" } }} history={{}} isUnitTest={true} location="/task/view/draft/70" /></Router>);
            await new Promise((r) => setTimeout(r, 5000));
        });
        expect(content.getByText("Task - Details")).toBeInTheDocument();
        // checking Task details and specification 
        expect(content.getAllByText('Observation').length).toBe(1);
        expect(content.getByText('Observation')).toBeInTheDocument();


        expect(content.getByLabelText("specification[correlator][frequency_resolution]")).toBeInTheDocument();
        const freqRes = content.getByLabelText("specification[correlator][frequency_resolution]");
        expect(freqRes.value).toBe('3.05');
        expect(content.getByLabelText("specification[correlator][time_resolution]")).toBeInTheDocument();
        const timeRes = content.getByLabelText("specification[correlator][time_resolution]");
        expect(timeRes.value).toBe('1');
        expect(content.getByLabelText("specification[station_configuration][SAPs][0][frequency]")).toBeInTheDocument();
        const freqSAP = content.getByLabelText("specification[station_configuration][SAPs][0][frequency]");
        expect(freqSAP.value).toBe('99.9-147.6');



        await waitFor(() => expect(content.getByRole("textbox", { name: "specification[station_configuration][SAPs][0][digital_pointing][angle1]" })).toBeInTheDocument());
        await waitFor(() => expect(content.getByRole("textbox", { name: "specification[station_configuration][SAPs][0][digital_pointing][angle2]" })).toBeInTheDocument());
        const angle1El = content.getByRole("textbox", { name: "specification[station_configuration][SAPs][0][digital_pointing][angle1]" });
        const angle1E2 = content.getByRole("textbox", { name: "specification[station_configuration][SAPs][0][digital_pointing][angle2]" });

        expect(angle1El.value).toBe('03h06m00s');
        expect(angle1E2.value).toBe('89d59m00s');

    });
})